#!/usr/bin/env python

from setuptools import setup

setup(name='mime',
      version='0.0.1',
      keywords='mime types',
      description='mime types',
      license='MIT License',
      url='https://github.com/liluo/mime',
      author='liluo',
      author_email='i@liluo.org',

      py_modules=['mime'],
      include_package_data=True,
      platforms='any',
      install_requires=[])
